<?php

/*
 * LMS version 1.3.4 Terok
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: dbview.php,v 1.19 2004/03/11 17:24:21 lukasz Exp $
 */

$layout['pagetitle'] = "Podgld bazy danych";

$database = $LMS->DatabaseFetchContent($_GET['db']);

if($_GET['rawmode']=="true")
{
	$database['rawmode'] = TRUE;
	if($_GET['save']=="true")
	{
		header("Content-Type: application/octetstream");
		header("Content-Disposition: attachment; filename=lms-backup-".date("Ymd-His",$_GET['db']).".sql");
	}
	else
		header("Content-Type: text/plain; charset=ISO-8859-2");
}

$SMARTY->assign('database',$database);
if(!$database['rawmode'])
	$SMARTY->display('header.html');
$SMARTY->display('dbview.html');
if(!$database['rawmode'])
	$SMARTY->display('footer.html');
?>